
Changelog
=========

1.2.3 (2024-08-29)
------------------
* Added education to the demographics model

1.2.0 (2024-07-31)
------------------
* Added Health model

1.1.4 (2024-07-30)
------------------
* Added AVAILABLE_MODELS_NAMES and AVAILABLE_MODELS to top level import

1.1.1 (2024-07-28)
------------------
* Economics model added
* Added collection classes ``DatagardenModels`` and ``DatagardenModelKeys``

1.0.1 (2024-07-26)
------------------
* First full release on PyPI
